==> react-form-builder-1.9.0.tgz: package/lib/Checkbox/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { field } from '../prop-types';
import MoleculeCheckboxField from '@s-ui/react-molecule-checkbox-field';
import IconCheck from '../Icons/IconCheck';

var Checkbox = function Checkbox(_ref) {
  var checkbox = _ref.checkbox,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors;
  var errorMessages = errors[checkbox.id];
  var checked = 'false';

  try {
    checked = JSON.parse(checkbox.value);
  } catch (e) {
    console.error('Impossible to convert to json checkbox value', checkbox);
  }

  var onChangeCallback = function onChangeCallback(e) {
    return onChange(checkbox.id, JSON.stringify(e.target.checked));
  }; // transform constraints to props


  var constraints = checkbox.constraints || [];
  var checkboxProps;
  checkboxProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property;

    return _objectSpread({}, acc, {}, (constraint === null || constraint === void 0 ? void 0 : (_constraint$property = constraint.property) === null || _constraint$property === void 0 ? void 0 : _constraint$property.notnull) === '' && {
      required: true
    });
  }, checkboxProps);
  checkboxProps = _objectSpread({}, checkboxProps, {
    id: checkbox.id,
    label: checkbox.label,
    checked: checked,
    value: checked,
    checkedIcon: IconCheck,
    onChange: onChangeCallback,
    tabIndex: tabIndex,
    intermediate: false
  }, checkbox.disabled && {
    disabled: true
  }, {}, checkbox.hidden && {
    hidden: true
  }, {}, !!errorMessages && {
    errorText: errorMessages.join('\n')
  });

  if (checkboxProps.hidden) {
    return null;
  }

  return React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Switch sui-FormBuilder-" + (checkboxProps.id || tabIndex)
  }, React.createElement(MoleculeCheckboxField, checkboxProps));
};

Checkbox.displayName = 'Switch';
export default Checkbox;

==> react-form-builder-1.11.0.tgz: package/lib/Checkbox/index.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeCheckboxField from '@s-ui/react-molecule-checkbox-field';
import IconCheck from '../Icons/IconCheck';

var Checkbox = function Checkbox(_ref) {
  var checkbox = _ref.checkbox,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors;
  var errorMessages = errors[checkbox.id];
  var checked = 'false';

  try {
    checked = JSON.parse(checkbox.value);
  } catch (e) {
    console.error('Impossible to convert to json checkbox value', checkbox);
  }

  var onChangeCallback = function onChangeCallback(e) {
    return onChange(checkbox.id, JSON.stringify(e.target.checked));
  }; // transform constraints to props


  var constraints = checkbox.constraints || [];
  var checkboxProps;
  checkboxProps = constraints.reduce(function (acc, constraint) {
    var _constraint$property;

    return _objectSpread({}, acc, {}, (constraint === null || constraint === void 0 ? void 0 : (_constraint$property = constraint.property) === null || _constraint$property === void 0 ? void 0 : _constraint$property.notnull) === '' && {
      required: true
    });
  }, checkboxProps);
  checkboxProps = _objectSpread({}, checkboxProps, {
    id: checkbox.id,
    label: checkbox.label,
    checked: checked,
    value: checked,
    checkedIcon: IconCheck,
    onChange: onChangeCallback,
    tabIndex: tabIndex,
    intermediate: false
  }, checkbox.disabled && {
    disabled: true
  }, {}, checkbox.hidden && {
    hidden: true
  }, {}, !!errorMessages && {
    errorText: errorMessages.join('\n')
  });

  if (checkboxProps.hidden) {
    return null;
  }

  return React.createElement("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Switch sui-FormBuilder-" + (checkboxProps.id || tabIndex)
  }, React.createElement(MoleculeCheckboxField, checkboxProps));
};

Checkbox.displayName = 'Switch';
export default React.memo(Checkbox, createComponentMemo('checkbox'));
